function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */
/// <reference types="../../../cypress/support"/>
import React, { useState } from 'react';
import { EuiButton } from '../button';
import { EuiPopover } from '../popover';
import { EuiSelectable } from './selectable';
import { jsx as ___EmotionJSX } from "@emotion/react";
var options = [{
  label: 'Titan',
  'data-test-subj': 'titanOption'
}, {
  label: 'Enceladus'
}, {
  label: "Pandora is one of Saturn's moons, named for a Titaness of Greek mythology"
}];

var EuiSelectableListboxOnly = function EuiSelectableListboxOnly(args) {
  return ___EmotionJSX(EuiSelectable, _extends({
    options: options
  }, args), function (list) {
    return ___EmotionJSX(React.Fragment, null, list);
  });
};

var EuiSelectableWithSearchInput = function EuiSelectableWithSearchInput(args) {
  return ___EmotionJSX(EuiSelectable, _extends({
    searchable: true,
    options: options
  }, args), function (list, search) {
    return ___EmotionJSX(React.Fragment, null, search, list);
  });
};

describe('EuiSelectable', function () {
  describe('with a `searchable` configuration', function () {
    it('has no accessibility errors', function () {
      var onChange = cy.stub();
      cy.realMount(___EmotionJSX(EuiSelectableWithSearchInput, {
        onChange: onChange
      }));
      cy.checkAxe();
    });
  });
  describe('without a `searchable` configuration', function () {
    it('has no accessibility errors', function () {
      var onChange = cy.stub();
      cy.realMount(___EmotionJSX(EuiSelectableListboxOnly, {
        "aria-label": "No search box",
        onChange: onChange
      }));
      cy.checkAxe();
    });
  });
  describe('nested in `EuiPopover` component', function () {
    var EuiSelectableNested = function EuiSelectableNested() {
      var _useState = useState(false),
          _useState2 = _slicedToArray(_useState, 2),
          isPopoverOpen = _useState2[0],
          setIsPopoverOpen = _useState2[1];

      var onChange = function onChange() {};

      var onClosePopover = function onClosePopover() {};

      var onButtonClick = function onButtonClick() {
        setIsPopoverOpen(!isPopoverOpen);
      };

      var button = ___EmotionJSX(EuiButton, {
        iconType: "arrowDown",
        iconSide: "right",
        onClick: onButtonClick
      }, "Show popover");

      return ___EmotionJSX(EuiPopover, {
        id: "data-cy-popover-1",
        panelPaddingSize: "s",
        button: button,
        isOpen: isPopoverOpen,
        closePopover: onClosePopover
      }, ___EmotionJSX(EuiSelectableWithSearchInput, {
        "aria-label": "With popover",
        options: options,
        onChange: onChange
      }, function (list) {
        return ___EmotionJSX(React.Fragment, null, list);
      }));
    };

    it('has no accessibility errors', function () {
      cy.realMount(___EmotionJSX(EuiSelectableNested, null));
      cy.get('button').realClick();
      cy.get('li[role=option]').first(); // Make sure the EuiSelectable is rendered before a11y check

      cy.checkAxe();
    });
  });
});